/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef FBODY_H
#define FBODY_H

#include "fpm.h"
#include "wGroup.h"
#include <vector>
#include <map>

namespace fpm
{

/**
 * @brief Manage a body immersed in the fluid (lifting surface)
 * @authors Adrien Crovato
 */
class FPM_API Body : public tbox::Group
{
public:
    double Cl;                                                  ///< lift coefficient
    double Cd;                                                  ///< drag coefficient
    double Cs;                                                  ///< sideforce coefficient
    double Cm;                                                  ///< pitch moment coefficient (positive nose-up)
    std::vector<double> cLoadX;                                 ///< x-component of aerodynamic load normalized by dynamic pressure
    std::vector<double> cLoadY;                                 ///< y-component of aerodynamic load normalized by dynamic pressure
    std::vector<double> cLoadZ;                                 ///< z-component of aerodynamic load normalized by dynamic pressure
    std::vector<tbox::Node *> nodes;                            ///< nodes of the surface
    std::map<tbox::Node *, std::vector<tbox::Element *>> neMap; ///< map between nodes and adjacent elements
    std::vector<Wake *> wakes;                                  ///< wake(s) attached to the lifting surface

    Body(std::shared_ptr<tbox::MshData> _msh, std::string const &name, std::vector<std::string> const &teNames, double xF);
    ~Body() { std::cout << "~Body()\n"; }

    virtual void save(std::string const &name);

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace fpm

#endif // FBODY_H
