/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @brief Compute the wall-clock (ellasped) time from "start" to "stop"
 */
inline double Timer::getWall() const
{
    return std::chrono::duration<double>(tE - tS).count();
}

/**
 * @brief Compute the cpu (user) time from "start" to "stop"
 */
inline double Timer::getCpu() const
{
    return (cE - cS) / (double)CLOCKS_PER_SEC;
}