/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef FWAKE_H
#define FWAKE_H

#include "fpm.h"
#include "wGroup.h"
#include "wTag.h"
#include <map>

namespace fpm
{

/**
 * @brief Manage the wake attached to a lifting body
 * @authors Adrien Crovato
 */
class FPM_API Wake : public tbox::Group
{
public:
    std::map<tbox::Element *, std::pair<tbox::Element *, tbox::Element *>> wkMap; ///< wing-wake map

    Wake(std::shared_ptr<tbox::MshData> _msh, std::string const &name, tbox::Tag *const &wTag);
    ~Wake() {}

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace fpm

#endif // FWAKE_H
